.. SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
..
.. SPDX-License-Identifier: GPL-3.0-or-later

.. place re-used URLs here, then include this file
.. on your other RST sources.

.. _conda: https://conda.io
.. _idiap: http://www.idiap.ch
.. _python: http://www.python.org
.. _pip: https://pip.pypa.io/en/stable/
.. _mamba: https://mamba.readthedocs.io/en/latest/index.html

.. _ci-evaluation: https://towardsdatascience.com/five-confidence-intervals-for-proportions-that-you-should-know-about-7ff5484c024f
.. _credible-interval: https://en.wikipedia.org/wiki/Credible_interval
.. _confidence-interval: https://en.wikipedia.org/wiki/Confidence_interval
.. _beta distribution: https://en.wikipedia.org/wiki/Beta_distribution
.. _monte carlo simulation: https://en.wikipedia.org/wiki/Monte_Carlo_method
.. _cross-validation: https://en.wikipedia.org/wiki/Cross-validation_(statistics)
